STRVideoFeedItem class

Constructors

STRVideoFeedItem({required String id, String? title, String? name, required int index, required bool seen, String? previewUrl, String? actionUrl, List<STRProductItem>? actionProducts, int? currentTime, List<VideoFeedComponent>? feedItemComponentList})
STRVideoFeedItem.fromJson(Map<String, dynamic> json)
factory

Properties

actionProducts List<STRProductItem>?
final
actionUrl String?
final
currentTime int?
final
feedItemComponentList List<VideoFeedComponent>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
index int
final
name String?
final
previewUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seen bool
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited