STRVideoFeedPayload class
- Inheritance
-
- Object
- STRPayload
- STRVideoFeedPayload
Constructors
- STRVideoFeedPayload({STRVideoFeedGroup? group, STRVideoFeedItem? feedItem, VideoFeedComponent? component})
-
STRVideoFeedPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- component → VideoFeedComponent?
-
final
- feedItem → STRVideoFeedItem?
-
final
- group → STRVideoFeedGroup?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited