PlacementCartUpdateEvent class
Constructors
- PlacementCartUpdateEvent({required PlacementWidget widget, STRCartItem? item, required String responseId})
-
PlacementCartUpdateEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → STRCartItem?
-
final
- responseId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → PlacementWidget
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited